pydoro 🍅
============
*Terminal Pomodoro Timer*

.. image:: https://github.com/JaDogg/pydoro/raw/master/images/logo.png

Installation 🎉
-----------------
Install via pipx:

.. code-block::

    $ pipx install pydoro

Done.

On windows you may try the packaged .exe file. See the releases_ page.

Usage 📖
---------
* Run :code:`pydoro` to launch.

.. image:: https://github.com/JaDogg/pydoro/raw/master/images/animation.gif

Credits 🙇‍♂️
------------------
* playsound.py - For playing audio file, Copyright (c) 2016 Taylor_ Marks
* prompt-tookit - For creating TUI
* b15.wav - Dana_ robinson designs, CC0 from 

.. _releases: https://github.com/JaDogg/pydoro/releases
.. _Taylor: https://github.com/TaylorSMarks/playsound
.. _Dana: https://freesound.org/s/377639/


Why ? 🤔
------------
* I wanted to follow `Pomodoro Technique`_.
* I don't like to use mobile apps or web apps.
* No user info is stored, tracked or shared.
* I spend lot of time on my Terminal.
* Written in Python 🐍.

.. _Pomodoro Technique: https://en.wikipedia.org/wiki/Pomodoro_Technique


Copyright ⚖
----------------
This software is Copyright (c) 2019 Bhathiya Perera.

See the LICENSE file for more information.
